@@ -1,6 +1,9 @@
 from enum import Enum
 
-from typing_extensions import Literal
+try:
+    from typing import Literal
+except ImportError:
+    from typing_extensions import Literal
 
 from ..base import BaseType
 
